==> haskell-retry-0.9.3.1-52-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-L3RN4HYWnqg3NE8fCwbpq7
key:                  retry-0.9.3.1-L3RN4HYWnqg3NE8fCwbpq7
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  fda626c0e3e57090e9a5a66a053e720d
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-L3RN4HYWnqg3NE8fCwbpq7
depends:
    base-4.16.4.0 exceptions-0.10.4 ghc-prim-0.8.0 mtl-2.2.2
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-retry-0.9.3.1-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-retry.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 retry
version:              0.9.3.1
visibility:           public
id:                   retry-0.9.3.1-Fap5Fp1VeQnKGDjOv9V7f7
key:                  retry-0.9.3.1-Fap5Fp1VeQnKGDjOv9V7f7
license:              BSD-3-Clause
copyright:            Ozgun Ataman, Soostone Inc
maintainer:           ozgun.ataman@soostone.com
author:               Ozgun Ataman
homepage:             http://github.com/Soostone/retry
synopsis:             Retry combinators for monadic actions that may fail
description:
    This package exposes combinators that can wrap arbitrary
    monadic actions. They run the action and potentially retry
    running it with some configurable delay for a configurable
    number of times.
    The purpose is to make it easier to work with IO and
    especially network IO actions that often experience temporary
    failure and warrant retrying of the original action. For
    example, a database query may time out for a while, in which
    case we should hang back for a bit and retry the query instead
    of simply raising an exception.

category:             Control
abi:                  9e8dc3abf5b648a70f8cca5724085055
exposed:              True
exposed-modules:      Control.Retry UnliftIO.Retry
import-dirs:          /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
library-dirs:         /usr/lib/ghc-9.2.8/site-local/retry-0.9.3.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-retry
hs-libraries:         HSretry-0.9.3.1-Fap5Fp1VeQnKGDjOv9V7f7
depends:
    base-4.16.4.0 exceptions-0.10.4 ghc-prim-0.8.0 mtl-2.2.2
    random-1.2.1.2-F9rVStWFtZE3PBeMKQuK89 transformers-0.5.6.2
    unliftio-core-0.2.1.0-2wlRerPMhUe3AYGiMsYOzn

haddock-interfaces:   /usr/share/doc/haskell-retry/html/retry.haddock
haddock-html:         /usr/share/doc/haskell-retry/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
